#ifndef H_RPMMI_PY
#define H_RPMMI_PY

/** \ingroup py_c
 * \file python/rpmmi-py.h
 */

/** \name Type: _rpm.mi */
/*@{*/

/** \ingroup py_c
 */
typedef struct rpmmiObject_s rpmmiObject;

/** \ingroup py_c
 */
struct rpmmiObject_s {
    PyObject_HEAD
    PyObject *md_dict;		/*!< to look like PyModuleObject */
    rpmdbMatchIterator mi;
} ;

/** \ingroup py_c
 */
/*@unchecked@*/
extern PyTypeObject rpmmi_Type;

__BEGIN_DECLS
/** \ingroup py_c
 */
/*@null@*/
rpmmiObject * rpmmi_Wrap(rpmdbMatchIterator mi)
	/*@*/;

__END_DECLS
/*@}*/

#endif
